@@ -113,77 +113,13 @@ var MailMigrator = {
     let xulStore = Cc["@mozilla.org/xul/xulstore;1"].getService(Ci.nsIXULStore);
 
     try {
-      // Initially, we checked if currentUIVersion < 1, and stripped the
-      // persisted "collapsed" property from folderPaneBox if it wasn't.
-      // However, the initial implementation of migrateUI swallowed up
-      // exceptions, and bumped the value of UI_VERSION_PREF regardless.
-      // Now, instead, we fail to bump the UI_VERSION_PREF if something goes
-      // wrong, and we've moved the folderPaneBox operation into
-      // currentUIVersion < 2 just in case the operation failed for some of
-      // our users the first time.
-      if (currentUIVersion < 2) {
-        // We want to remove old settings that collapse the folderPaneBox
-        if (xulStore.hasValue(MESSENGER_DOCURL, "folderPaneBox", "collapsed")) {
-          // We want to override this, and set it to false.  We should really
-          // be ignoring this persist attribute, anyhow.
-          xulStore.removeValue(MESSENGER_DOCURL, "folderPaneBox", "collapsed");
-        }
+      // UI versions below 5 could only exist in an old profile with localstore.rdf
+      // file used for the XUL store. Since TB55 this file is no longer read.
+      // Since UI version 5, the xulstore.json file is being used, so we only
+      // support those version here, see bug 1371898.
 
-        // We want to remove the throbber from the menubar on Linux and
-        // Windows, and from the mail-toolbar on OSX.
-        let mailBarId = (Services.appinfo.OS == "Darwin") ?
-          "mail-bar3" : "mail-toolbar-menubar2";
-        let cs = xulStore.getValue(MESSENGER_DOCURL, mailBarId, "currentset");
-
-        if (cs && cs.includes("throbber-box")) {
-          cs = cs.replace(/(^|,)throbber-box($|,)/, "$1$2");
-          xulStore.setValue(MESSENGER_DOCURL, mailBarId, "currentset", cs);
-        }
-      }
-
-      // In UI version 3, we move the QFB button from the tabbar toolbar to
-      // to the mail toolbar.
-      if (currentUIVersion < 3) {
-        let cs = xulStore.getValue(MESSENGER_DOCURL, "tabbar-toolbar", "currentset");
-        if (cs && cs.includes("qfb-show-filter-bar")) {
-          cs = cs.replace(/(^|,)qfb-show-filter-bar($|,)/, "$1$2");
-          xulStore.setValue(MESSENGER_DOCURL, "tabbar-toolbar", "currentset", cs);
-        }
-
-        let cs3 = xulStore.getValue(MESSENGER_DOCURL, "mail-bar3", "currentset");
-        if (cs3 && !cs3.includes("qfb-show-filter-bar")) {
-          if (cs3.includes("gloda-search")) {
-            // Put the QFB toggle before the gloda-search and any of
-            // spring / spacer / separator.
-            cs3 = cs3.replace(/(^|,)([spring,|spacer,|separator,]*)gloda-search($|,)/,
-                             "$1qfb-show-filter-bar,$2gloda-search$3");
-          } else {
-            // If there's no gloda-search, just put the QFB toggle at the end
-            cs3 += ",qfb-show-filter-bar";
-          }
-          xulStore.setValue(MESSENGER_DOCURL, "mail-bar3", "currentset", cs3);
-        }
-      }
-
-      // In UI version 4, we add the chat button to the mail toolbar.
-      if (currentUIVersion < 4) {
-        let cs = xulStore.getValue(MESSENGER_DOCURL, "mail-bar3", "currentset");
-        if (cs && !cs.includes("button-chat")) {
-          if (cs.includes("button-newmsg")) {
-            // Put the chat button after the newmsg button.
-            cs = cs.replace(/(^|,)button-newmsg($|,)/,
-                            "$1button-newmsg,button-chat$2");
-          } else if (cs.includes("button-address")) {
-            // If there's no newmsg button, put the chat button before the address book button.
-            cs = cs.replace(/(^|,)button-address($|,)/,
-                            "$1button-chat,button-address$2");
-          } else {
-            // Otherwise, just put the chat button at the end.
-            cs += ",button-chat";
-          }
-          xulStore.setValue(MESSENGER_DOCURL, "mail-bar3", "currentset", cs);
-        }
-      }
+      // However, there's a tiny left-over. For new profiles (running the entire
+      // migration) we need to autohide the menubar.
 
       // In UI version 5, we add the AppMenu button to the mail toolbar and
       // collapse the main menu by default if the user has no accounts
@@ -192,25 +128,6 @@ var MailMigrator = {
       // think of any better way of determining whether this profile is new
       // or not.
       if (currentUIVersion < 5) {
-        /**
-         * Helper function that attempts to add the AppMenu button to the
-         * end of a toolbar with ID aToolbarID. Fails silently if this is
-         * not possible, as is typical within our UI migration code.
-         *
-         * @param aToolbarID the ID of the toolbar to add the AppMenu to.
-         */
-        let addButtonToEnd = function(aToolbarID, aButtonID) {
-          let cs = xulStore.getValue(MESSENGER_DOCURL, aToolbarID, "currentset");
-          if (cs && !cs.includes(aButtonID)) {
-            // Put the AppMenu button at the end.
-            cs += "," + aButtonID;
-            xulStore.setValue(MESSENGER_DOCURL, aToolbarID, "currentset", cs);
-          }
-        }.bind(this);
-
-        addButtonToEnd("mail-bar3", "button-appmenu");
-        addButtonToEnd("chat-toobar", "button-chat-appmenu");
-
         if (Services.prefs.getBoolPref("mail.main_menu.collapse_by_default") &&
             MailServices.accounts.accounts.length == 0) {
           xulStore.setValue(MESSENGER_DOCURL, "mail-toolbar-menubar2", "autohide", "true");
