@@ -25,6 +25,7 @@
 #include "pkix/Result.h"
 #include "pkix/pkixtypes.h"
 #include "smime.h"
+#include "mozilla/StaticMutex.h"
 
 using namespace mozilla;
 using namespace mozilla::psm;
@@ -228,18 +229,6 @@ nsCMSMessage::CommonVerifySignature(unsigned char* aDigestData,
     goto loser;
   }
 
-  if (NSS_CMSSignedData_HasDigests(sigd)) {
-    SECAlgorithmID **existingAlgs = NSS_CMSSignedData_GetDigestAlgs(sigd);
-    if (existingAlgs) {
-      while (*existingAlgs) {
-        SECAlgorithmID *alg = *existingAlgs;
-        SECOidTag algOIDTag = SECOID_FindOIDTag(&alg->algorithm);
-        NSS_CMSSignedData_SetDigestValue(sigd, algOIDTag, NULL);
-        ++existingAlgs;
-      }
-    }
-  }
-
   if (aDigestData && aDigestDataLen)
   {
     SECOidTag oidTag;
@@ -247,6 +236,18 @@ nsCMSMessage::CommonVerifySignature(unsigned char* aDigestData,
     digest.data = aDigestData;
     digest.len = aDigestDataLen;
 
+    if (NSS_CMSSignedData_HasDigests(sigd)) {
+      SECAlgorithmID **existingAlgs = NSS_CMSSignedData_GetDigestAlgs(sigd);
+      if (existingAlgs) {
+        while (*existingAlgs) {
+          SECAlgorithmID *alg = *existingAlgs;
+          SECOidTag algOIDTag = SECOID_FindOIDTag(&alg->algorithm);
+          NSS_CMSSignedData_SetDigestValue(sigd, algOIDTag, NULL);
+          ++existingAlgs;
+        }
+      }
+    }
+
     if (!GetIntHashToOidHash(aDigestType, oidTag)) {
       rv = NS_ERROR_CMS_VERIFY_BAD_DIGEST;
       goto loser;
@@ -390,6 +391,7 @@ private:
   {
     MOZ_ASSERT(!NS_IsMainThread());
 
+    mozilla::StaticMutexAutoLock lock(sMutex);
     nsresult rv;
     if (!mDigestData.IsEmpty()) {
       rv = mMessage->VerifyDetachedSignature(
@@ -413,8 +415,12 @@ private:
   nsCOMPtr<nsISMimeVerificationListener> mListener;
   nsCString mDigestData;
   int16_t mDigestType;
+
+  static mozilla::StaticMutex sMutex;
 };
 
+mozilla::StaticMutex SMimeVerificationTask::sMutex;
+
 nsresult nsCMSMessage::CommonAsyncVerifySignature(nsISMimeVerificationListener *aListener,
                                                   unsigned char* aDigestData, uint32_t aDigestDataLen,
                                                   int16_t aDigestType)
