@@ -28,6 +28,7 @@ XPCOMUtils.defineLazyModuleGetters(this, {
   PrivateBrowsingUtils: "resource://gre/modules/PrivateBrowsingUtils.jsm",
   Integration: "resource://gre/modules/Integration.jsm",
   PermissionUI: "resource:///modules/PermissionUI.jsm",
+  AppConstants: "resource://gre/modules/AppConstants.jsm",
 });
 
 XPCOMUtils.defineLazyGetter(this, "DebuggerServer", () => {
@@ -866,6 +867,10 @@ SuiteGlue.prototype = {
    * having updates off and an old build that likely should be updated.
    */
   _shouldShowUpdateWarning: function () {
+    // If the Updater is not available we don't show the warning.
+    if (!AppConstants.MOZ_UPDATER) {
+      return false;  
+    }
     // Look for an unconditional override pref. If set, do what it says.
     // (true --> never show, false --> always show)
     try {
